@@ -1,5 +1,5 @@
 //
-// (C) Copyright 2011-2013 Sergey A. Babkin.
+// (C) Copyright 2011-2014 Sergey A. Babkin.
 // This file is a part of Triceps.
 // See the file COPYRIGHT for the copyright notice and license information
 //
@@ -61,7 +61,7 @@ UTESTCASE primaryIndex(Utest *utest)
 	UT_ASSERT(tt->getErrors().isNull());
 	UT_ASSERT(!tt->getErrors()->hasError());
 
-	Autoref<Table> t = tt->makeTable(unit, Table::EM_IGNORE, "t");
+	Autoref<Table> t = tt->makeTable(unit, "t");
 	UT_ASSERT(!t.isNull());
 	UT_ASSERT(t->getInputLabel() != NULL);
 	UT_ASSERT(t->getLabel() != NULL);
@@ -85,7 +85,7 @@ UTESTCASE uninitialized(Utest *utest)
 
 	UT_ASSERT(tt);
 
-	Autoref<Table> t = tt->makeTable(unit, Table::EM_IGNORE, "t");
+	Autoref<Table> t = tt->makeTable(unit, "t");
 	UT_ASSERT(t.isNull());
 }
 
@@ -108,7 +108,7 @@ UTESTCASE withError(Utest *utest)
 	UT_ASSERT(!tt->getErrors().isNull());
 	UT_ASSERT(tt->getErrors()->hasError());
 
-	Autoref<Table> t = tt->makeTable(unit, Table::EM_IGNORE, "t");
+	Autoref<Table> t = tt->makeTable(unit, "t");
 	UT_ASSERT(t.isNull());
 }
 
@@ -131,14 +131,14 @@ UTESTCASE tableops(Utest *utest)
 	UT_ASSERT(tt->getErrors().isNull());
 	UT_ASSERT(!tt->getErrors()->hasError());
 
-	Autoref<Table> t = tt->makeTable(unit, Table::EM_IGNORE, "t");
+	Autoref<Table> t = tt->makeTable(unit, "t");
 	UT_ASSERT(!t.isNull());
 
 	IndexType *prim = tt->findSubIndex("primary");
 	UT_ASSERT(prim != NULL);
 
 	// other instance, for checking of errors
-	Autoref<Table> t2 = tt->makeTable(unit, Table::EM_IGNORE, "t2");
+	Autoref<Table> t2 = tt->makeTable(unit, "t2");
 	UT_ASSERT(!t2.isNull());
 	IndexType *prim2 = tt->findSubIndex("primary");
 	UT_ASSERT(prim2 != NULL);
@@ -150,7 +150,7 @@ UTESTCASE tableops(Utest *utest)
 		);
 	UT_ASSERT(tt3);
 	tt3->initialize();
-	Autoref<Table> t3 = tt3->makeTable(unit, Table::EM_IGNORE, "t3");
+	Autoref<Table> t3 = tt3->makeTable(unit, "t3");
 	UT_ASSERT(!t3.isNull());
 	IndexType *prim3 = tt3->findSubIndex("primary");
 	UT_ASSERT(prim3 != NULL);
