@@ -1,5 +1,5 @@
 //
-// (C) Copyright 2011-2013 Sergey A. Babkin.
+// (C) Copyright 2011-2014 Sergey A. Babkin.
 // This file is a part of Triceps.
 // See the file COPYRIGHT for the copyright notice and license information
 //
@@ -13,7 +13,7 @@ namespace TRICEPS_NS {
 NameSet::NameSet()
 { }
 
-NameSet::NameSet(const NameSet *other) :
+NameSet::NameSet(const vector<string> *other) :
 	vector<string> (*other)
 { }
 
