@@ -1,5 +1,5 @@
 //
-// (C) Copyright 2011-2013 Sergey A. Babkin.
+// (C) Copyright 2011-2014 Sergey A. Babkin.
 // This file is a part of Triceps.
 // See the file COPYRIGHT for the copyright notice and license information
 //
@@ -10,24 +10,24 @@
 #define __Triceps_NameSet_h__
 
 #include <common/Common.h>
-#include <mem/Starget.h>
+#include <mem/Mtarget.h>
 
 namespace TRICEPS_NS {
 
 // The ordered set of names gets used to specify subsets of fields,
 // in particular, the index keys.
-class NameSet : public Starget, public vector<string>
+class NameSet : public Mtarget, public vector<string>
 {
 public:
 	NameSet();
-	NameSet(const NameSet *other);
+	NameSet(const vector<string> *other);
 	NameSet(const vector<string> &other);
 	// Constructors duplicated as make() for syntactically better usage.
 	static NameSet *make()
 	{
 		return new NameSet;
 	}
-	static NameSet *make(const NameSet *other)
+	static NameSet *make(const vector<string> *other)
 	{
 		return new NameSet(other);
 	}
