@@ -1,5 +1,5 @@
 #
-# (C) Copyright 2011-2014 Sergey A. Babkin.
+# (C) Copyright 2011-2015 Sergey A. Babkin.
 # This file is a part of Triceps.
 # See the file COPYRIGHT for the copyright notice and license information
 #
@@ -9,7 +9,7 @@ package Triceps::Fields;
 
 sub CLONE_SKIP { 1; }
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.0.1';
 
 use Carp;
 
@@ -164,6 +164,7 @@ sub makeTranslation # (optName => optValue, ...)
 			rowTypes => [ undef, sub { &Triceps::Opt::ck_mandatory(@_); &Triceps::Opt::ck_ref(@_, "ARRAY", "Triceps::RowType") } ],
 			filterPairs => [ undef, sub { &Triceps::Opt::ck_mandatory(@_); &Triceps::Opt::ck_ref(@_, "ARRAY", "ARRAY") } ],
 			saveCodeTo => [ undef, sub { &Triceps::Opt::ck_refscalar(@_) } ],
+			_simulateCodeError => [ undef ],
 		}, @_);
 
 	# reset the saved source code
@@ -204,14 +205,20 @@ sub makeTranslation # (optName => optValue, ...)
 			);
 		}';
 
-	my $result_rt = Triceps::RowType->new(@rowdef);
-		# XXX extended error "$myname: Invalid result row type specification: $! ";
+	my $result_rt = Triceps::wrapfess 
+		"$myname: Invalid result row type specification:",
+		sub { Triceps::RowType->new(@rowdef); };
 
 	${$opts->{saveCodeTo}} = $gencode if (defined($opts->{saveCodeTo}));
 
+	if ($opts->{_simulateCodeError}) {
+		$gencode .= ")";
+	}
+
 	# compile the translation function
 	my $func = eval $gencode
-		or confess "$myname: error in compilation of the function:\n  $@\nfunction text:\n$gencode ";
+		or confess "$myname: error in compilation of the generated function:\n  $@function text:\n"
+		. Triceps::Code::numalign($gencode, "  ") . "\n";
 
 	return ($result_rt, $func);
 }
